##
## FEIR. Fundamentos Estadísticos para Investigación. Int. a R
## Regresión lineal simple
## Curso 2014/15
##--------------------------------------------------------------

# Leemos el archivo 
produccion <- read.table( "40B-production.csv", sep = ";", head = TRUE )

str( produccion )

# Estadísticos descriptivos
summary( produccion )

# Diagrama de dispersión
plot( produccion$articulos, produccion$tiempo, xlab = "articulos", ylab = "tiempo")
# Correlación
cor.test( produccion$tiempo, produccion$articulos )

#---------
# Ajuste del modelo 
model <- lm( tiempo ~ articulos, data = produccion )
model                               
 
# Resumen del modelo
summary( model )
 

#---------
## Bondad de ajuste del modelo

# Tabla Anova
options( show.signif.stars=FALSE )
anova( model )
summary( model )$r.squared
 
# Representación del ajuste
plot( produccion$articulos, produccion$tiempo, xlab = "articulos", ylab = "tiempo" )
abline(model, col="red")

#---------
## Diagnóstico del modelo

produccion$fitted.model <- fitted( model )
produccion$residuals.model <- residuals( model ) 
produccion$rstudent.model <- rstudent( model )
 
# Errores residuales vs Valores ajustados
plot( model, which = 1 )

#--------- 
## Normalidad
  # Gráfico Q-Q 
plot( model, which = 2 )
 
  # Test de normalidad 
ks.test( produccion$rstudent.model, "pnorm" )

#---------
## Homocedasticidad

  # Gráfico de escala-ubicación
plot( model, which = 3 )
 
# Homogeneidad de varianzas
library( lmtest )
bptest( model, studentize = FALSE, data = produccion )
 
#---------
## Autocorrelación
dwtest( model, alternative = "two.sided", data = produccion )


#---------
## Observaciones influyentes. Atípicos

plot( model, which = 5 )
 
infl <- influence.measures( model )
summary( infl )

#---------
## Predicción

# Intervalos de predicción
dfp <- data.frame( articulos = seq (55 , 345 ,by = 10 ) )
pred.ip <- predict( model, dfp, interval = "prediction", 
                    se.fit = TRUE, data = produccion )
head( pred.ip$fit )
 
# Intervalos de confianza

pred.ic <- predict( model, dfp, interval = "confidence",
                    se.fit = TRUE, data =produccion )
head( pred.ic$fit )
 
# Bandas de confianza y predicción

plot( produccion$articulos, produccion$tiempo, pch = 20,
      ylim = range ( produccion$articulos, pred.ip, na.rm = TRUE ),
      xlab = "articulos", ylab = "tiempo" )
# Añadimos las bandas
matlines ( dfp$articulos, pred.ic$fit, lty = c( 1 ,2 ,2 ), lwd =1.5, col = 3 )
matlines ( dfp$articulos, pred.ip$fit, lty = c( 1 ,3 ,3 ), lwd = 1.5, col = 2 )


