#------------------------------------------------------------------------------
###
### Regresión lineal múltiple
###
#------------------------------------------------------------------------------
# Leemos el archivo 
library( car ); data( Prestige )
df <- Prestige [ , 1:4 ]
str( df )

# Estadísticos descriptivos
summary( df )

#-------------
# Diagrama de dispersión

dfo<-data.frame(prestige = df$prestige, education = df$education,
                income = df$income, women = df$women)
pairs(dfo, panel = panel.smooth, main = "Prestige data" )

# Correlación
cor( df, use = "everything", method = "pearson" )

#---------
## Ajuste del modelo 

# Modelo inicial 
modeli <- lm(prestige ~ ., data = df )
modeli                             



# Resumen del modelo inicial
summary( modeli )

#---------
## Selección paso a paso del mejor modelo
step(modeli, direction = "backward")

modelo <- lm( formula = prestige ~ education + income, data = df )
# Resumen del modelo final
summary( modelo )

#---------
## Bondad de ajuste del modelo

# Tabla Anova
anova( modelo )
summary( modelo )$adj.r.squared

#---------
## Diagnóstico del modelo
df$fitted.modelo <- fitted( modelo )
df$residuals.modelo <- residuals( modelo ) 
df$rstudent.modelo <- rstudent( modelo )


# Errores residuales vs Valores ajustados
plot( modelo, which = 1 )

#---------
## Normalidad
plot( modelo, which = 2 )
ks.test( df$rstudent.modelo, "pnorm" )

## Homocedasticidad
plot( modelo, which = 3 )
library( lmtest )
bptest( modelo, studentize = FALSE, data = df )


dwtest( modelo, alternative = "two.sided",
        data = df )

#---------
## Observaciones influyentes. Atípicos
plot( modelo, which = 5 )

# Valores atípicos
library( car )
outlierTest( modelo )

# Observaciones influyentes
infl <- influence.measures( modelo )
summary( infl )

# Observaciones influyentes
influencePlot( modelo, id.n = 2 )

# Distancias de Cook

cook <- cooks.distance( modelo )
labels <- rownames( df )

library(faraway)
halfnorm( cook, 3, labs = labels, ylab = "Distancia de Cook" )


#---------
## Predicción

# Intervalos de predicción
dbp<-data.frame( education = seq( 6, 16, length = 102 ), 
                 income = 6798, women = 29, census = 5400 )
pred <- predict( modelo, dbp, interval = "prediction",
                 se.fit = TRUE, data = dfbeb )
head( pred$fit )



# Intervalos de confianza

pred.ic <- predict( modelo, dbp, interval = "confidence",
                    se.fit = TRUE, data =df )
head( pred.ic$fit )


#---------
# Multicolinealidad

vif( modelo )
sqrt( vif( modelo ) ) > 2


