### Conjunto de datos para trabajar

df <- read.table( "ejemplo.csv", sep = ";",
                  
                  head = TRUE )

head(df)


df$raza <- factor( df$raza )

df$genero <- factor( df$genero )



### ANOVA de dos vías. Supuestos


fit6 <- bartlett.test( df$m0 ~ df$genero )

fit6

fit7 <- shapiro.test(df$m0[df$genero==1])

fit8 <- shapiro.test(df$m0[df$genero==2])



fit2E <- aov( m0 ~ raza * genero, data = df )

summary(fit2E)


interaction.plot( df$raza, df$genero, df$m0,
                  
                  ylim = c( 10, 60 ),
                  
                  col = c("orange", "blue" ),
                  
                  lty = c( 1, 12 ), lwd = 3,
                  
                  ylab = "media del valor m0",
                  
                  xlab = "raza", trace.label = "genero" )



# ANOVA de dos vías. EL orden importa

fit2E <- aov( m0 ~ raza * genero, data = df )

summary(fit2E)


fit2E2 <- aov( m0 ~ genero * raza, data = df )

summary(fit2E2)


dfMOD <- df[ 1:11, ]

dfMOD


fit2E3 <- aov( m0 ~ raza * genero, data = dfMOD )

summary( fit2E3 )


fit2E4 <- aov( m0 ~ genero * raza, data = dfMOD )

summary( fit2E4 )



# ANOVA de dos vías. Datos no balanceados


options(contrasts = c("contr.sum","contr.poly"))

fit2E5 <- aov( m0 ~ genero * raza, data = dfMOD )

library( "car" )

Anova( fit2E5, type = "III" )


fit2E6 <- aov( m0 ~ raza * genero, data = dfMOD )

Anova( fit2E6, type = "III" )




# ANOVA con medidas repetidas. Reestructurar los datos

library( reshape2 )

df2 <- melt( df, id = c( "id", "genero", "raza" ),
             
             measure = c( "m0", "m1", "m3" ),
             
             variable.name = "mes",
             
             value.name = "valor")

head( df2 )



# ANOVA de medidas repetidas con R. aov()


df2$id <- factor(df2$id)

fit1D <- aov(valor ~ mes + Error(id / mes ),
             
             data = df2 )

summary( fit1D )


# ANOVA de medidas repetidas con R. ezANOVA()


library( ez )

options( contrasts = c( "contr.sum", "contr.poly" ) )

df2$id <- factor(df2$id)

fit12 <-ezANOVA(data = df2, dv = .( valor ),
                
                wid = .( id ), within = .( mes ),
                
                type = 3)

fit12


# Modelos mixtos ANOVA con R. aov()


fitM <- aov( valor ~ genero * mes + Error( id / mes ),
             
             data = df2 )

summary( fitM )



# Modelos mixtos ANOVA con R. ezANOVA()


options( contrasts = c( "contr.sum", "contr.poly" ) )

fit13 <-ezANOVA(data = df2, dv = .( valor ),
                
                wid = .( id ), between = .(genero),
                
                within = .( mes ), type = 3)

fit13



# Modelos mixtos ANOVA con R, 2 factores entre sujetos. aov()


fitM <- aov( valor ~ genero * raza * mes +
               
               Error( id / genero * raza * mes ), data = df2 )

summary( fitM )


# Iteration género y mes


interaction.plot( df2$mes, df2$genero, df2$valor,
                  
                  ylim = c( 10, 60 ),
                  
                  col = c("orange", "blue" ),
                  
                  lty = c( 1, 2, 12 ), lwd = 3,
                  
                  ylab = "media del valor",
                  
                  xlab = "mes", trace.label = "genero" )



# Iteration raza y mes


interaction.plot( df2$mes, df2$raza, df2$valor,
                  
                  ylim = c( 10, 60 ),
                  
                  col = c("orange", "black", "blue"),
                  
                  lty = c( 1, 12 ), lwd = 3,
                  
                  ylab = "media del valor",
                  
                  xlab = "mes", trace.label = "raza" )



# Modelos mixtos ANOVA con R, 2 factores entre sujetos. ezANOVA()


options( contrasts = c( "contr.sum", "contr.poly" ) )

?contr.sum

fit14 <-ezANOVA(data = df2, dv = .( valor ),
                
                wid = .( id ), between = .(genero, raza),
                
                within = .( mes ), type = 3)

fit14



# Fin


Continuará...
