# Cargamos el conjunto de datos "cars" del paquete 'datasets'
data( cars ) 
# Contiene la velocidad ( speed (mph) )y la ditancia de frenado (dist (foot) ) 
# de coches de los años 20

df<-cars
# Análisis preliminar de los datos
str( df ) 
summary( df ) 

# Correlación
cor( df$speed, df$dist )

# Diagrama de dispersión 
par( mfrow = c ( 1, 1 ) )
plot( df$speed,df$dist )


# Representamos los datos en una nube de puntos de tal manera que los coches con velocidades bajas
# también tenían distancias de frenado cortas. Conforme aumenta la velocidad, la distancia de 
# frenado también aumentan, sin embargo no se trata de una relación de crecimiento 1:1 .
# Por ejemplo, hay variedad de distancias de frenado para un valor de velocidad 20.
df$dist[ df$speed==20 ]

# El rango de valores va de 32 a 64 foot. Se aprecia mucha variación. 


#------------
# Ajustamos la recta de regresión a los datos. Buscamos la recta que haga mínima la suma de cuadrados
# de los residuos (e. d. la suma de cuadrados de las diferencias entre los valores medidos y ajustados
#                  de y para un valor dado x)

modelo <- lm( dist ~ speed, data = df)
abline( modelo, col = 2 )

# Recordad que estamos ajustando una recta de la forma Y=mX+b a los datos, donde (m=pendiente 
# y b es la ordenada en el origen. Veamos sus valores:
summary( modelo )

# La recta que obtenemos es Y = speed * 3.9324 -17.5791.

# Si analizamos tanto la recta como el gráfico vemos que no tiene sentido que el ajuste tenga
# una ordenada en el origen que no sea igual a 0. Tiene más sentido que un coche con velocidad cero
# no tenga distancia de frenado y uno que se muy despacio aún tenga distancia de frenado.

# Hacemos que  la ordenada en el origen sea 0 (Y = mX)
#---------------------------------------------
modelo2 <- lm( dist~speed-1, data = df )
plot( df$dist ~ df$speed-1 )

abline( modelo2, col=2 )
abline (modelo, col=4 )
summary( modelo2 )

# La nueva recta es  Y = 2.9091X. A simple vista podría parecer que la recta no pasa
# por el (0,0), pero si ampliamos el gráfico en el origen...
plot( df$dist ~ df$speed-1, ylim = c(0, 10), xlim = c(0,5))
abline( modelo2, col = 2 ) # roja
abline (modelo, col = 4 ) # azul

# Supuestos del modelo

# 1) Errores distribuidos normalmente e independentes
# 2) La media de los erroes es cero y tienen varianza constante
# 3) Todos los puntos están medidos con la misma exactitud y tienen la misma influencia

# Obtenemos los estadísticos
df$fitted.modelo2 <- fitted( modelo2 )
df$residuals.modelo2 <- residuals( modelo2 ) 
df$rstudent.modelo2 <- rstudent( modelo2 )

# Gráfico 1 
plot( modelo2, which = 1 )
# El primer gráfico representa los residuos frente a los valores ajustados.
# Los residuos deben estar uniformemente distribuidos por encima y por debajo de la línea del cero.
#   * Una tendencia en la media de los rediuos sugiere una violación del supuesto de independencia
# de las variables respuesta.
dwtest( modelo2, alternative = "two.sided", data = df )

#   * Una tendencia en la variabilidad de los residuos incumple el supuesto de varianza constante. 
# Estos datos parecen mostrar una leve tendencia de aumento de la varianza de izquierda a derecha.


# Gráfico 2 
plot( modelo2, which = 2 )
ks.test( df$rstudent.modelo2, "pnorm" )

# Representa los residuos estandarizados frente a los cuantiles de una distribución normal estándar.
# Si los residuos se distribuyen normalmente los datos se deben dibujar a lo largo de la línea diagonal. 
  # En este gráfico los datos no parecen estar distribuidos normalmente.

# Gráfico 3 
plot( modelo2, which = 3 )
library( lmtest )
bptest( modelo2, studentize = FALSE, data = df )
# NO HAY HOMOCEDASTICIDAD
# Gráfico de escala-localización en el que los residuos están estandarizados mediante
# sus deviaciones estándar.
# Se usa para detectar si los residuos se distribuyen de forma constante en el rango de valores ajustados.
# Vemos una tendencia en los datos, los valores altos muestran mayor varianza.

# Gráfico 4
plot( modelo2, which = 5 )
# Muestra los residuales estandarizados enfrentado contra los Leverage.
# Muestra los datos que están ejerciendo la mayor influencia.
# Si la línea de distancia de Cook abarca a algno de los datos, sugiere que el análisis puede ser
# muy sensible a ese punto y puede ser prudente repetir el análisis con los datos excluidos. 
# Podríamos excluir el punto 49, que parece ser un caso atípico, pero no lo haremos por ahora. (Escala-Ubicación parcela)


# Podemos representar los cuatro gráficos juntos:
par( mfrow = c( 2, 2 ) )
plot( modelo2, data= df ) )

# Como hemos detectado un incremento en la varianza, no hay homocedasticidad aplicamos
# una transformación

# Aplicamos el logaritmo a los datos.
df$ln.speed <-log( df$speed ) 
df$ln.dist <- log( df$dist )
modelog <- lm(ln.dist ~ ln.speed-1, data = df) 
plot( modelog )
# Se aprecia una menor tendencia en todos los gráficos, incluso en el gráfico QQ-plot que parece
# ajustar mucho mejor.

# Veamos un resumen del modelo 
summary( modelog)

# Observamos que ahora el modelo explica casi un 99% de la varianza de los datos. 


