#  Un oficial de personal en una empresa realiza unas pruebas de aptitud a 25 solicitantes para puestos de entrada en el organismo.
# Los 25 solicitantes fueron aceptados independientemente de su puntuacin en la prueba. Despus de un perodo de prueba, a cada solicitante
# se le midi su competitividad en el trabajo en cuatro test.
# 
# a. Encontrar cuatro modelos de regresin tomando subconjuntos de las variables y di cual es el mejor modelo segn el criterio de R^a.
# b. Puesto que hay relativamente poca diferencia en el R^a para los cuatro modelos, qu otros criterios utilizara para ayudar en la
# seleccin del mejor modelo? 
# c. El uso de regresin por pasos hacia delante, encontrar el mejor subconjunto de variables de prediccin para predecir la competitividad
# en el trabajo.
# d. Cmo es el mejor subconjunto de acuerdo a la seleccin por pasos en comparacin con el mejor modelo de acuerdo con el criterio Ra.p?
#----------------------------------------------------------------------------------------------------------------------------------

# Leemos los datos
df <- read.table( "testEmpleo.csv", sep = ";", head = TRUE )
# Exploracin de los datos
summary( df ) 
str( df )

pairs( df, panel = panel.smooth )

# Matriz de correlacin
cor( df, use = "everything", method = "pearson" )
library( "psych" )
corr.test( df, use = "complete", method = "pearson" )

# Modelo de regresin mltiple
## Creamos el modelo de regresin
modelo <- lm( aptitud ~ ., data = df )
summary( modelo ) # analizamos el modelo inicial

## Seleccin del modelo mediante los mtodos paso a paso Mtodo hacia atrs
step( modelo, direction = "backward" )

modelof <- lm( aptitud ~ test1 + test3 + test4, data = df )

# Anlisis del modelo final
summary( modelof )
anova( modelof )

## Diagnsitco del modelo
## Obtenemos los residuos del  modelof y valores ajustados
df$fitted.modelof <- fitted( modelof )
df$residuals.modelof <- residuals( modelof )
df$rstudent.modelof <- rstudent( modelof )


plot( modelof, which = 1 ) 
### Autocorrelacin
dwtest( modelof, alternative = "two.sided", data = df)

# Normalidad
plot( modelof, which = 2 ) 
ks.test( df$rstudent.modelof, "pnorm" )

### Homogeneidad de varianzas
plot( modelof, which = 3 ) 
library(lmtest)
bptest( modelof, studentize = FALSE, data = df)


### Valores influyentes y atpicos
plot( modelof, which = 5 ) 

library(car)
outlierTest( modelof )

### Anlisis de la influencia Tabla con las medidas de influencia
infl <- influence.measures( modelof )
summary( infl )
#### Grfico medidas influyentes
influencePlot( modelof, id.n = 2 )

#### Grfico de las distancias de Cook
cook <- cooks.distance( modelof)
labels <- rownames(df)
library(faraway)
halfnorm(cook, 3, labs = labels, ylab = "Distancia de Cook")


# Prediccin. 

# intervalo para una de las vbles.
x0 <- seq( min( df$test3 ), max( df$test3 ), length = length( df$test3 ) )

dbp <- data.frame(test1 = 103, test2 = 107, test3 = x0, test4 = 95)
pred <- predict(modelof, dbp, interval = "prediction", se.fit = TRUE, data = dfbeb)
head(pred$fit)


# Multicolinealidad
library( car )
vif( modelof )
sqrt(vif( modelof ) ) > 2
